==> magic3_2.2.19_src.tar.gz: magic3/widgets/admin_main/include/container/admin_mainConfigwidgetWidgetContainer.php <==
<?php
/**
 * コンテナクラス
 *
 * PHP versions 5
 *
 * LICENSE: This source file is licensed under the terms of the GNU General Public License.
 *
 * @package    Magic3 Framework
 * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 * @copyright  Copyright 2006-2011 Magic3 Project.
 * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
 * @version    SVN: $Id: admin_mainConfigwidgetWidgetContainer.php 4347 2011-09-24 11:39:00Z fishbone $
 * @link       http://www.magic3.org
 */
require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_mainBaseWidgetContainer.php');

class admin_mainConfigwidgetWidgetContainer extends admin_mainBaseWidgetContainer
{
	const JQUERY_IFRAME_FILE = '/jquery/jquery.iframe-auto-height.plugin.1.5.0.min.js';	// jQueryプラグイン
	
	/**
	 * コンストラクタ
	 */
	function __construct()
	{
		// 親クラスを呼び出す
		parent::__construct();
	}
	/**
	 * テンプレートファイルを設定
	 *
	 * _assign()でデータを埋め込むテンプレートファイルのファイル名を返す。
	 * 読み込むディレクトリは、「自ウィジェットディレクトリ/include/template」に固定。
	 *
	 * @param RequestManager $request		HTTPリクエスト処理クラス
	 * @param object         $param			任意使用パラメータ。そのまま_assign()に渡る
	 * @return string 						テンプレートファイル名。テンプレートライブラリを使用しない場合は空文字列「''」を返す。
	 */
	function _setTemplate($request, &$param)
	{	
		return 'configwidget.tmpl.html';
	}
	/**
	 * テンプレートにデータ埋め込む
	 *
	 * _setTemplate()で指定したテンプレートファイルにデータを埋め込む。
	 *
	 * @param RequestManager $request		HTTPリクエスト処理クラス
	 * @param object         $param			任意使用パラメータ。_setTemplate()と共有。
	 * @param								なし
	 */
	function _assign($request, &$param)
	{
		// 設定画面を作成するウィジェットのウィジェットIDを取得
		$task = $request->trimValueOf(M3_REQUEST_PARAM_OPERATION_TASK);
		list($taskName, $widgetId) = explode('_', $task, 2);
		
		$todo = $request->trimValueOf(M3_REQUEST_PARAM_OPERATION_TODO);		// 実行処理
		$url = '?cmd=configwidget&widget=' . $widgetId;
		if (!empty($todo)) $url .= '&' . urldecode($todo);
		$this->tmpl->addVar("_widget", "url", $url);
	}
	/**
	 * JavascriptファイルをHTMLヘッダ部に設定
	 *
	 * JavascriptファイルをHTMLのheadタグ内に追加出力する。
	 * _assign()よりも後に実行される。
	 *
	 * @param RequestManager $request		HTTPリクエスト処理クラス
	 * @param object         $param			任意使用パラメータ。
	 * @return string 						Javascriptファイル。出力しない場合は空文字列を設定。
	 */
	function _addScriptFileToHead($request, &$param)
	{
		$scriptArray = array($this->getUrl($this->gEnv->getScriptsUrl() . self::JQUERY_IFRAME_FILE));
		return $scriptArray;
	}
}
?>

==> magic3_2.4.17_src.tar.gz: magic3/widgets/admin_main/include/container/admin_mainConfigwidgetWidgetContainer.php <==
<?php
/**
 * コンテナクラス
 *
 * PHP versions 5
 *
 * LICENSE: This source file is licensed under the terms of the GNU General Public License.
 *
 * @package    Magic3 Framework
 * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 * @copyright  Copyright 2006-2012 Magic3 Project.
 * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
 * @version    SVN: $Id: admin_mainConfigwidgetWidgetContainer.php 4999 2012-07-01 02:49:00Z fishbone $
 * @link       http://www.magic3.org
 */
require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_mainBaseWidgetContainer.php');

class admin_mainConfigwidgetWidgetContainer extends admin_mainBaseWidgetContainer
{
//	const JQUERY_IFRAME_FILE = '/jquery/jquery.iframe-auto-height.plugin.1.5.0.min.js';	// jQueryプラグイン
	const JQUERY_IFRAME_FILE = '/jquery/jquery.iframe-auto-height.plugin.1.7.1.min.js';	// jQueryプラグイン
	
	/**
	 * コンストラクタ
	 */
	function __construct()
	{
		// 親クラスを呼び出す
		parent::__construct();
	}
	/**
	 * テンプレートファイルを設定
	 *
	 * _assign()でデータを埋め込むテンプレートファイルのファイル名を返す。
	 * 読み込むディレクトリは、「自ウィジェットディレクトリ/include/template」に固定。
	 *
	 * @param RequestManager $request		HTTPリクエスト処理クラス
	 * @param object         $param			任意使用パラメータ。そのまま_assign()に渡る
	 * @return string 						テンプレートファイル名。テンプレートライブラリを使用しない場合は空文字列「''」を返す。
	 */
	function _setTemplate($request, &$param)
	{	
		return 'configwidget.tmpl.html';
	}
	/**
	 * テンプレートにデータ埋め込む
	 *
	 * _setTemplate()で指定したテンプレートファイルにデータを埋め込む。
	 *
	 * @param RequestManager $request		HTTPリクエスト処理クラス
	 * @param object         $param			任意使用パラメータ。_setTemplate()と共有。
	 * @param								なし
	 */
	function _assign($request, &$param)
	{
		// 設定画面を作成するウィジェットのウィジェットIDを取得
		$task = $request->trimValueOf(M3_REQUEST_PARAM_OPERATION_TASK);
		list($taskName, $widgetId) = explode('_', $task, 2);
		
		$todo = $request->trimValueOf(M3_REQUEST_PARAM_OPERATION_TODO);		// 実行処理
		$url = '?cmd=configwidget&widget=' . $widgetId;
		if (!empty($todo)) $url .= '&' . urldecode($todo);
		$this->tmpl->addVar("_widget", "url", $url);
	}
	/**
	 * JavascriptファイルをHTMLヘッダ部に設定
	 *
	 * JavascriptファイルをHTMLのheadタグ内に追加出力する。
	 * _assign()よりも後に実行される。
	 *
	 * @param RequestManager $request		HTTPリクエスト処理クラス
	 * @param object         $param			任意使用パラメータ。
	 * @return string 						Javascriptファイル。出力しない場合は空文字列を設定。
	 */
	function _addScriptFileToHead($request, &$param)
	{
		$scriptArray = array($this->getUrl($this->gEnv->getScriptsUrl() . self::JQUERY_IFRAME_FILE));
		return $scriptArray;
	}
}
?>
